@@ -1,9 +1,11 @@
 package Net::Douban::Collection;
+
 BEGIN {
-  $Net::Douban::Collection::VERSION = '1.06_1';
+    $Net::Douban::Collection::VERSION = '1.07_1';
 }
 
 use Moose;
+use MooseX::StrictConstructor;
 use Carp qw/carp croak/;
 use Net::Douban::Atom;
 with 'Net::Douban::Roles::More';
@@ -15,7 +17,7 @@ has 'collectionID' => (
 
 has 'collection_url' => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => 'Url',
     lazy    => 1,
     default => sub { shift->base_url . '/collection' },
 );
@@ -23,22 +25,23 @@ has 'collection_url' => (
 sub get_collection {
     my ($self, %args) = @_;
     $args{collectionID} ||= $self->collectionID;
+    croak "collectionID missing" unless $args{collectionID};
     return Net::Douban::Atom->new(
-        $self->collection_url . "/$args{collectionID}");
+        $self->get($self->collection_url . "/$args{collectionID}"));
 }
 
 sub get_user_collection {
     my ($self, %args) = @_;
     my $uid = delete $args{userID} or croak "userID needed!";
-    exists $args{cat} or croak "cat needed!";
-    return Net::Douban::Atom->new($self->user_url . "/$uid/collection", %args,
-    );
+    exists $args{cat} or croak "cat(category) needed!";
+    return Net::Douban::Atom->new(
+        $self->get($self->user_url . "/$uid/collection", %args));
 }
 
 sub add_collection {
     my ($self, %args) = @_;
     croak "post xml needed" unless exists $args{xml};
-    return $self->post($self->collection_url, $args{xml},);
+    return $self->post($self->collection_url, xml => $args{xml});
 }
 
 sub put_collection {
@@ -46,12 +49,13 @@ sub put_collection {
     $args{collectionID} ||= $self->collectionID;
     croak "put xml needed" unless exists $args{xml};
     return $self->put($self->collection_url . "/$args{collectionID}",
-        $args{xml},);
+        xml => $args{xml},);
 }
 
 sub delete_collection {
     my ($self, %args) = @_;
     $args{collectionID} ||= $self->collectionID;
+    croak "collectionID missing" unless $args{collectionID};
     return $self->delete($self->collection_url . "/$args{collectionID}");
 
 }
@@ -70,12 +74,12 @@ __END__
 
 =head1 VERSION
 
-version 1.06_1
+version 1.07_1
 
 =head1 SYNOPSIS
 
 	use Net::Douban::Collection;
-	my $user = Net::Douban::Collection->new(
+	my $coll = Net::Douban::Collection->new(
         
 		collectionID => '....',
         # or
@@ -104,7 +108,7 @@ Interface to douban.com API collection section
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://douban.com/service/apidoc>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://www.douban.com/service/apidoc/reference/collection>
 
 =head1 AUTHOR
 
@@ -118,4 +122,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
\ No newline at end of file
+=cut
