@@ -1,9 +1,12 @@
 package Net::Douban::Doumail;
+
 BEGIN {
-  $Net::Douban::Doumail::VERSION = '1.06_1';
+    $Net::Douban::Doumail::VERSION = '1.07_1';
 }
 
 use Moose;
+use MooseX::StrictConstructor;
+use Net::Douban::Atom;
 use Carp qw/carp croak/;
 with 'Net::Douban::Roles::More';
 
@@ -14,11 +17,15 @@ has 'doumailID' => (
 
 has 'doumail_url' => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => 'Url',
     lazy    => 1,
     default => sub { shift->base_url . '/doumail' },
 );
 
+before qw/inbox unread outbox get_doumail/ => sub {
+    croak "oauth needed" unless $_[0]->has_oauth;
+};
+
 sub inbox {
     my ($self, %args) = @_;
     return Net::Douban::Atom->new(
@@ -39,33 +46,37 @@ sub outbox {
 
 sub get_doumail {
     my ($self, %args) = @_;
-    $args{doumailID} ||= $self->doumailID;
+    $args{mailID} ||= $self->mailID;
+    croak "mailID needed" unless defined $args{mailID};
     return Net::Douban::Atom->new(
-        $self->get($self->doumail_url . "/$args{doumailID}", %args));
+        $self->get($self->doumail_url . "/$args{mailID}", %args));
 }
 
 sub post_doumail {
     my ($self, %args) = @_;
     croak "post xml needed!" unless $args{xml};
-    return $self->post($self->doumail_url . 's', $args{xml},);
+    return $self->post($self->doumail_url . 's', xml => $args{xml});
 }
 
 sub delete_doumail {
     my ($self, %args) = @_;
-    $args{doumailID} ||= $self->doumailID;
-    return $self->delete($self->doumail_url . "/$args{doumailID}",);
+    $args{mailID} ||= $self->mailID;
+    croak "mailID needed" unless defined $args{mailID};
+    return $self->delete($self->doumail_url . "/$args{mailID}");
 }
 
 sub mark_read {
     my ($self, %args) = @_;
-    $args{doumailID} ||= $self->doumailID;
-    croak "post xml needed!" unless $args{xml};
-    return $self->put($self->doumail_url . "/$args{doumailID}", $args{xml},);
+    $args{mailID} ||= $self->mailID;
+    croak "mailID needed"   unless defined $args{mailID};
+    croak "put xml needed!" unless $args{xml};
+    return $self->put($self->doumail_url . "/$args{mailID}",
+        xml => $args{xml});
 }
 
 sub delete {
     my ($self, %args) = @_;
-    croak "post xml needed!" unless $args{xml};
+    croak "delete xml needed!" unless $args{xml};
     return $self->delete($self->doumail_url, $args{xml});
 }
 
@@ -86,12 +97,12 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 VERSION
 
-version 1.06_1
+version 1.07_1
 
 =head1 SYNOPSIS
 
 	use Net::Douban::Doumail;
-	my $user = Net::Douban::Doumail->new(
+	my $mail= Net::Douban::Doumail->new(
         ...
 	);
 
@@ -125,7 +136,7 @@ Interface to douban.com API  mail section
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http//douban.com/service/apidoc>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://douban.com/service/apidoc/reference/douamil>
 
 =head1 AUTHOR
 
@@ -139,4 +150,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
\ No newline at end of file
+=cut
