@@ -1,9 +1,11 @@
 package Net::Douban::Entry;
+
 BEGIN {
-  $Net::Douban::Entry::VERSION = '1.06_1';
+    $Net::Douban::Entry::VERSION = '1.07_1';
 }
 
 use Moose;
+use MooseX::StrictConstructor;
 use Net::Douban::DBSubject;
 use Carp qw/carp croak/;
 
@@ -96,24 +98,24 @@ sub subject {
     return $k;
 }
 
-sub DESTROY { }
-our $AUTOLOAD;
-
-sub AUTOLOAD {
-
-    #	my $self = shift;
-    #	my $class = ref $self ? ref $self : $self;
-    (my $name = $AUTOLOAD) =~ s/.*:://g;
-    return if $name eq 'DESTROY';
-    my $sub = <<SUB;
-	sub $name {
-		my \$self =  shift;
-		return \$self->get($name);
-	}
-SUB
-    eval($sub);    ## the same as *$name = $sub;
-    goto &$name;
-}
+#sub DESTROY { }
+#our $AUTOLOAD;
+#
+#sub AUTOLOAD {
+#
+#    #	my $self = shift;
+#    #	my $class = ref $self ? ref $self : $self;
+#    (my $name = $AUTOLOAD) =~ s/.*:://g;
+#    return if $name eq 'DESTROY';
+#    my $sub = <<SUB;
+#	sub $name {
+#		my \$self =  shift;
+#		return \$self->get($name);
+#	}
+#SUB
+#    eval($sub);    ## the same as *$name = $sub;
+#    goto &$name;
+#}
 1;
 
 __END__
@@ -128,7 +130,7 @@ Net::Douban::Entry
 
 =head1 VERSION
 
-version 1.06_1
+version 1.07_1
 
 =head1 SYNOPSIS
 	
@@ -154,10 +156,6 @@ Many functions not listed here are documented in L<XML::Atom::Entry>
 
 see L<Net::Douban::Atom>
 
-=item AUTOLOAD
-
-see L<Net::Douban::Atom>
-
 =item content
 
 	$entry->content();
@@ -198,4 +196,4 @@ Copyright (C) 2010 by Woosley.Xu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
\ No newline at end of file
+at your option, any later version of Perl 5 you may have available.
