@@ -1,9 +1,11 @@
 package Net::Douban::Token;
+
 BEGIN {
-  $Net::Douban::Token::VERSION = '1.06_1';
+    $Net::Douban::Token::VERSION = '1.07_1';
 }
 
 use Moose;
+use MooseX::StrictConstructor;
 use Env qw/HOME/;
 use Carp qw/carp croak/;
 with 'Net::Douban::Roles::More';
@@ -16,7 +18,7 @@ has 'instance' => (
 
 has 'token_url' => (
     is      => 'rw',
-    isa     => 'Str',
+    isa     => 'Url',
     lazy    => 1,
     default => sub { shift->base_url . '/access_token' },
 );
@@ -72,6 +74,6 @@ __END__
 
 =head1 VERSION
 
-version 1.06_1
+version 1.07_1
 
-=cut
\ No newline at end of file
+=cut
